<?php

namespace App\Service\Action;

use App\Service\Response\Classes\Response;
use App\Service\Response\ResponseServiceInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

abstract class BaseActionService implements ActionServiceInterface
{
    protected ?ResponseServiceInterface $responseService;

    public function __construct(
        ResponseServiceInterface $baseResponseService,
    )
    {
        $this->responseService = $baseResponseService;
    }

    public function getResponse(): JsonResponse
    {
        if ($this->validate()) {
            $this->runAction();
        }

        if ($this->responseService) {
            return $this->responseService->getResponse();
        }

        $response = new Response();
        $response->addError('Ошибка получения ответа');
        return $response->getResponse();
    }
}